@@ -9,6 +9,7 @@ class AutoEmbedPaginator(object):
         self.bot = ctx.bot
         self.current_page = 0
         self.auto_footer = kwargs.get("auto_footer", False)
+        self.remove_reactions = kwargs.get("remove_reactions", True)
         self.control_emojis = ('⏮️', '⏪', '🔐', '⏩', '⏭️')
         self.timeout = int(kwargs.get("timeout", 60))
     async def run(self, embeds):
@@ -19,6 +20,7 @@ class AutoEmbedPaginator(object):
         msg = await self.ctx.send(embed=self.embeds[0])
         for emoji in self.control_emojis:
             await msg.add_reaction(emoji)
+        msg = await msg.channel.fetch_message(msg.id)
         def check(reaction, user):
             return user == self.ctx.author and reaction.message.id == msg.id and str(reaction.emoji) in self.control_emojis
         while True:
@@ -34,32 +36,38 @@ class AutoEmbedPaginator(object):
                 reaction, user = await self.bot.wait_for("reaction_add",check=check)
             if str(reaction.emoji) == self.control_emojis[0]:
                 self.current_page = 0
-                await msg.remove_reaction(str(reaction.emoji), user)
+                if self.remove_reactions:
+                    await msg.remove_reaction(str(reaction.emoji), user)
                 if self.auto_footer:
                     self.embeds[0].set_footer(text=f'({self.current_page+1}/{len(self.embeds)})')
                 await msg.edit(embed=self.embeds[0])
             elif str(reaction.emoji) == self.control_emojis[1]:
                 self.current_page = self.current_page-1
                 self.current_page = 0 if self.current_page<0 else self.current_page
-                await msg.remove_reaction(str(reaction.emoji), user)
+                if self.remove_reactions:
+                    await msg.remove_reaction(str(reaction.emoji), user)
                 if self.auto_footer:
                     self.embeds[self.current_page].set_footer(text=f'({self.current_page+1}/{len(self.embeds)})')
                 await msg.edit(embed=self.embeds[self.current_page])
             elif str(reaction.emoji) == self.control_emojis[2]:
                 self.current_page = 0
-                await msg.clear_reactions()
+                for reaction in msg.reactions:
+                    if reaction.message.author.id == self.bot.user.id:
+                        await msg.remove_reaction(str(reaction.emoji), reaction.message.author)
                 return
                 break
             elif str(reaction.emoji) == self.control_emojis[3]:
                 self.current_page = self.current_page + 1
                 self.current_page = len(self.embeds)-1 if self.current_page > len(self.embeds)-1 else self.current_page
-                await msg.remove_reaction(str(reaction.emoji), user)
+                if self.remove_reactions:
+                    await msg.remove_reaction(str(reaction.emoji), user)
                 if self.auto_footer:
                     self.embeds[self.current_page].set_footer(text=f'({self.current_page+1}/{len(self.embeds)})')
                 await msg.edit(embed=self.embeds[self.current_page])
             elif str(reaction.emoji) == self.control_emojis[4]:
                 self.current_page = len(self.embeds)-1
-                await msg.remove_reaction(str(reaction.emoji), user)
+                if self.remove_reactions:
+                    await msg.remove_reaction(str(reaction.emoji), user)
                 if self.auto_footer:
                     self.embeds[len(self.embeds)-1].set_footer(text=f'({self.current_page+1}/{len(self.embeds)})')
                 await msg.edit(embed=self.embeds[len(self.embeds)-1])
@@ -74,6 +82,7 @@ class CustomEmbedPaginator(object):
         self.control_emojis = []
         self.control_commands = []
         self.auto_footer = kwargs.get("auto_footer", False)
+        self.remove_reactions = kwargs.get("remove_reactions", False)
     def add_reaction(self, emoji, command):
         self.control_emojis.append(emoji)
         self.control_commands.append(command)
@@ -106,6 +115,7 @@ class CustomEmbedPaginator(object):
         msg = await self.ctx.send(embed=self.embeds[0])
         for emoji in self.control_emojis:
             await msg.add_reaction(emoji)
+        msg = await msg.channel.fetch_message(msg.id)
         def check(reaction, user):
             return user == self.ctx.author and reaction.message.id == msg.id and str(reaction.emoji) in self.control_emojis
         while True:
@@ -125,27 +135,31 @@ class CustomEmbedPaginator(object):
                     cmd = self.control_commands[index]
                     if cmd.lower() == "first":
                         self.current_page = 0
-                        await msg.remove_reaction(str(reaction.emoji), user)
+                        if self.remove_reactions:
+                            await msg.remove_reaction(str(reaction.emoji), user)
                         if self.auto_footer:
                             self.embeds[0].set_footer(text=f'({self.current_page+1}/{len(self.embeds)})')
                         await msg.edit(embed=self.embeds[0])
                     elif cmd.lower() == "last":
                         self.current_page = len(self.embeds)-1
-                        await msg.remove_reaction(str(reaction.emoji), user)
+                        if self.remove_reactions:
+                            await msg.remove_reaction(str(reaction.emoji), user)
                         if self.auto_footer:
                             self.embeds[len(self.embeds)-1].set_footer(text=f'({self.current_page+1}/{len(self.embeds)})')
                         await msg.edit(embed=self.embeds[len(self.embeds)-1])
                     elif cmd.lower() == "next":
                         self.current_page += 1
                         self.current_page = len(self.embeds)-1 if self.current_page > len(self.embeds)-1 else self.current_page
-                        await msg.remove_reaction(str(reaction.emoji), user)
+                        if self.remove_reactions:
+                            await msg.remove_reaction(str(reaction.emoji), user)
                         if self.auto_footer:
                             self.embeds[self.current_page].set_footer(text=f'({self.current_page+1}/{len(self.embeds)})')
                         await msg.edit(embed=self.embeds[self.current_page])
                     elif cmd.lower() == "back":
                         self.current_page = self.current_page-1
                         self.current_page = 0 if self.current_page<0 else self.current_page
-                        await msg.remove_reaction(str(reaction.emoji), user)
+                        if self.remove_reactions:
+                            await msg.remove_reaction(str(reaction.emoji), user)
                         if self.auto_footer:
                             self.embeds[self.current_page].set_footer(text=f'({self.current_page+1}/{len(self.embeds)})')
                         await msg.edit(embed=self.embeds[self.current_page])
@@ -156,7 +170,9 @@ class CustomEmbedPaginator(object):
                         break
                     elif cmd.lower() == "clear" or cmd.lower() == "lock":
                         self.current_page = 0
-                        await msg.clear_reactions()
+                        for reaction in msg.reactions:
+                            if reaction.message.author.id == self.bot.user.id:
+                                await msg.remove_reaction(str(reaction.emoji), reaction.message.author)
                         return
                         break
                     elif cmd.startswith("page"):
@@ -167,7 +183,8 @@ class CustomEmbedPaginator(object):
                             pg = len(embeds)-1
                         if pg < 0:
                             pg = 0
-                        await msg.remove_reaction(str(reaction.emoji), user)
+                        if self.remove_reactions:
+                            await msg.remove_reaction(str(reaction.emoji), user)
                         if self.auto_footer:
                             self.embeds[self.current_page].set_footer(text=f'({pg+1}/{len(self.embeds)})')
                         await msg.edit(embed=self.embeds[pg])
@@ -180,14 +197,16 @@ class CustomEmbedPaginator(object):
                             index = len(self.control_emojis)-1 if index > len(self.control_emojis)-1 else index
                             index = 0 if index < 0 else index
                             emoji = self.control_emojis[index]
-                            await msg.remove_reaction(str(reaction.emoji), user)
+                            if self.remove_reactions:
+                                await msg.remove_reaction(str(reaction.emoji), user)
                             await msg.remove_reaction(emoji, self.bot.user)
                             self.control_emojis.pop(index)
                             self.control_commands.pop(index)
                         else:
                             emoji = something
                             if emoji in self.control_emojis:
-                                await msg.remove_reaction(str(reaction.emoji), user)
+                                if self.remove_reactions:
+                                    await msg.remove_reaction(str(reaction.emoji), user)
                                 await msg.remove_reaction(emoji, self.bot.user)
                                 index = self.control_emojis.index(emoji)
                                 self.control_emojis.remove(emoji)
